@@ -1,5 +1,6 @@
 from django.forms.models import _get_foreign_key
 
+from is_core.config import settings
 from is_core.generic_views.table_views import TableViewMixin
 from is_core.generic_views.inlines import RelatedInlineView
 
@@ -21,6 +22,16 @@ class InlineTableView(TableViewMixin, RelatedInlineView):
             else self.fields
         )
 
+    def _get_export_fields(self):
+        return (
+            self.related_core.get_ui_export_fields(self.request) if self.related_core and self.export_fields is None
+            else self.export_fields
+        )
+
+    def _get_list_per_page(self):
+        list_per_page = self.related_core.get_list_per_page(self.request) if self.related_core else None
+        return list_per_page if list_per_page is not None else super()._get_list_per_page()
+
     def _get_api_url(self):
         return self.related_core.get_api_url(self.request)
 
